# Python files

`client.py`: implementation of WAVE+MQTT

`publisher.py`: example publisher with registration

`subscriber.py`: example subscriber; needs to be given permission inside `publisher.py` (read the source code)
